## Copyright (C) 1997, 1998, 1999  Jeffrey C. O'Neill
## Copyright (C) 1998, 1999  Boston University
## Copyright (C) 1997, 1998  Ecole Normale Superieure de Lyon
## Copyright (C) 1997  The Regents of the University of Michigan
## All Rights Reserved 
## Jeffrey O'Neill
##
##
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

function [tfr,t,f] = dwv0(x,t,fs);
%DWV0	Wigner-Ville time-frequency distribution as defined by Claasen/Mecklenbrauker.
%       Uses the signal oversampled to twice the initial rate.
%	[TFR,T,F]=DWV0(X,T,N) computes the Wigner-Ville distribution
%	of a discrete-time signal X
% 
%	X     : signal
%	T     : time instant(s)          (default : 1:length(X)).
%	FS    : sampling frequency       (default : 1).
%	TFR   : time-frequency representation.
%	F     : vector of normalized frequencies.
%
%	based on the code made by F. Auger. Copyright (c) 1996 by CNRS (France).

if (nargin == 0),
 error('At least one parameter required');
end;

[xrow,xcol] = size(x);
N=xrow;

if (nargin == 1),
  t=1:xrow; fs=1; trace=0;
elseif (nargin == 2),
  fs=1; trace=0;
elseif (nargin ==3),
  trace=0;
end;

[trow,tcol] = size(t);
if (xcol==0)|(xcol>1),
  error('X must have one column');
elseif (trow~=1),
  error('T must only have one row'); 
elseif (2^nextpow2(N)~=N),
  error('N must be a power of two');
end; 

% -- resample to twice the initial rate
x2=resample2x(x);
t2=2*t-1;
N2=2*N;

% -- compute lacf
tfr=lacf(x2,t2);

% -- make FFT
tfr= fft(tfr)/fs; 
tfr=real(tfr);

if (nargout==3),
 f=fs/2*(0:N-1)'/N;
end;

