%%
%% Copyright (C) 2005 Eric Chassande-Mottin, CNRS (France)
%%
%% This program may be freely copied under the terms of the 
%% GNU General Public License (GPL), version 2, or at your 
%% option any later version.
%%

%% generate a GW chirp and search with BCC

clear;

snr=10;

%% -- init
debug=0;              % save: yes=0, no=1

% -- signal
N=256; 
fs=1024; % Hz
fl=96;   % Hz
[s,ifl,difl,ddifl,cm]=gwchirp(N,fl/fs,N,fs);
M=cm/0.43;
printf("total mass = %2.2f solar mass\n",M);
fisco=205*(20/M)/fs;
printf("f LSCO = %2.1f Hz\n",fs*fisco);

%% -- generate noise and add
n=randn(N,1);
x=sqrt(2/N)*snr*real(s)+n;
%x=real(s);

%% -- compute TFR
w=dwv(x);
w=w(1:N,:);

%% -- search params
b=2;
Nr1=9;
Nr2=4;

%% -- calibrate search params
deltaf=fs/(2*N);
deltat=b/fs;
dotF=(Nr1-1)*deltaf/deltat;
ddotF=(Nr2-2)*deltaf/deltat^2;
t1=max(find(fs^2*difl<=dotF));
t2=max(find(fs^3*ddifl<=ddotF));

%% -- apply BCC
[l,m_cc]=dp_bcc(w,b,Nr1,1,Nr2);

%% -- make plots
t=1:b:N+1;
plot(ifl,";GW chirp;");
hold on;
plot(t,m_cc/2/N,";best CC;");
plot([t1 t1],[0 0.5],";limit regul. 1st;");
plot([t2 t2],[0 0.5],";limit regul. 2nd;");
plot([1 N],[fisco fisco],";ISCO;");
hold off
grid("on");
xlabel("time");
ylabel("frequency");
axis([1 N 0 0.5]);

if (debug==0)
  save -mat-binary figure0b.mat w m_cc fs ifl t1 t2 b N snr fisco
end;
