%%
%% Copyright (C) 2005 Eric Chassande-Mottin, CNRS (France)
%%
%% This program may be freely copied under the terms of the 
%% GNU General Public License (GPL), version 2, or at your 
%% option any later version.
%%

%% compare ROC curves of various detection algorithms, makes graphics

clear;

%% -- set terminal
debug=0; % 1: x11, 0: postscript

%% -- few constants
z95=1.96; % 95% confidence interval

%% -- load data
load figure2.mat
n_alg=rows(algo);

%% -- compute error bars
err_pfa=z95*sqrt(pfa_all.*(1-pfa_all)/n_trial);
err_pfd= z95*sqrt(pfd_all.*(1-pfd_all)/n_trial);

%% -- compute ROCs for clairvoyant quad. matched filter
idx=find(pfa_all(:)>0);
pfa_min=min(min(pfa_all(idx)));
n_thr=rows(pfa_all);
snr_fit=4.55;
[pfa_qmf,pd_qmf]=roc_matchedfilter(n_thr,pfa_min,snr_fit);

%% -- make plots
idx=1:5:n_thr;
errorbar(pfa_all(idx,1),pfd_all(idx,1),err_pfa(idx,1),err_pfd(idx,1),"~>");
hold on;
eval(sprintf("semilogx(pfa_qmf,pd_qmf,';qmf (fit: SNR=%2.2f);');",snr_fit));
for n=1:n_alg,
  str=strrep(algo(n,:),'_',' ');
  str=strrep(str,'2',' ');
  eval(sprintf("semilogx(pfa_all(:,n),pfd_all(:,n),';%s;');",str));
end;
hold off

__gnuplot_set__ key bottom right
eval(sprintf('title("receiver operator char. (N=%d, SNR=%2.1f)");',N,snr));
xlabel('false alarm rate');
ylabel('detection probability');
axis([pfa_min 1.0 0.5 1.0]);
grid("on");

%% gset term posts eps enhanced color dashed "helvetica" 20
%% gset output "figure2_N_%d_snr_%d.eps";',N,rho));

if (debug==0)
  printf("saving figure...");
  eval(sprintf('my_print("figure2_N_%d_snr_%d.eps","-depsc","-dashed","-FHelvetica:18");',N,snr));
  printf("done\n");
end;

%% -- relax
oneplot();
__gnuplot_set__ xtics autofreq
__gnuplot_set__ ytics autofreq
__gnuplot_set__ autoscale x
__gnuplot_set__ autoscale y
__gnuplot_set__ term x11
